Learn R Programming

tidylab (version 4.1.1)

tidylab_conflicts: Conflicts between the tidylab and other packages

Description

This function lists all the conflicts between packages in the tidylab and other packages that you have loaded.

This function lists all the conflicts between packages in the tidylab and other packages that you have loaded.

Usage

tidylab_conflicts()

tidylab_conflicts()

Arguments

Value

(tidylab_conflicts) A list with conflicted functions.

Details

There are four conflicts that are deliberately ignored: intersect, union, setequal, and setdiff from dplyr. These functions make the base equivalents generic, so shouldn't negatively affect any existing code.

If dplyr is one of the select packages, then the following four conflicts are deliberately ignored: intersect, union, setequal, and setdiff from dplyr. These functions make the base equivalents generic, so shouldn't negatively affect any existing code.

Examples

Run this code
# NOT RUN {
tidylab_conflicts()
tidylab_conflicts()
# }

Run the code above in your browser using DataLab